/* This file is part of nanolisp, a very small Lisp system.

Copyright (C) 2007  Luca Saiu

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>. */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <stdbool.h>
#include <assert.h>
#include "nanolisp.h"

#define USE_GC

#ifdef USE_GC
#include <gc/gc.h>
#endif

void* nanolisp_make_buffer(const size_t size_in_bytes){
#ifndef USE_GC
  /* This is only for testing: of course it's not acceptable to make all
     heap-allocated buffers become garbage! */
  void *result = malloc(size_in_bytes);
  assert(result != NULL);
  return result;
#else
  /* Just make the garbage collector procedure do all the work: */
  return GC_MALLOC(size_in_bytes);
#endif
}
