/* This file is part of nanolisp, a very small Lisp system.

Copyright (C) 2007  Luca Saiu

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>. */


#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <assert.h>
#include "nanolisp.h"

static void nanolisp_print_cdr(nanolisp_sexpression_t a){
  switch(nanolisp_get_type(a)){
  case nanolisp_empty_list_type:
    return;
  case nanolisp_cons_type:
    printf(" ");
    nanolisp_print(nanolisp_car(a));
    nanolisp_print_cdr(nanolisp_cdr(a));
    break;
  default:
    printf(" . ");
    nanolisp_print(a);
  }
}

void nanolisp_print(nanolisp_sexpression_t a){
  switch(nanolisp_get_type(a)){
  case nanolisp_integer_type:
    printf("%i", nanolisp_get_content(a)->integer_content);
    break;
  case nanolisp_symbol_type:
    printf("%s", nanolisp_get_symbol_as_c_string(a));
    break;
  case nanolisp_cons_type:
    printf("(");
    nanolisp_print(nanolisp_car(a));
    nanolisp_print_cdr(nanolisp_cdr(a));
    printf(")");
    break;
  case nanolisp_boolean_type:
    if(nanolisp_get_content(a)->boolean_content)
      printf("#t");
    else
      printf("#f");
    break;
  case nanolisp_empty_list_type:
    printf("()");
    break;
  case nanolisp_procedure_type:
    /* Let's not show the difference between a primitive procedure and a
       non-primitive procedure: it's not important for the user: */
  case nanolisp_primitive_procedure_type:
    printf("#<procedure>");
    break;
  default:
    assert(false);
  } // switch
}
